# pylint: disable=too-many-lines, missing-module-docstring
# This is trace specification version of 0.3.0
# Reference to SIMULATION_FLAG was causing this error:
# jsonschema.exceptions.RefResolutionError:
# Unresolvable JSON pointer: 'components/schemas/SIMULATION_FLAG'
# To fix it reference was copied
# "$ref": "#/components/schemas/SIMULATION_FLAG"
# Seems it is a bug on our side because schema looks valid
RPC_SPECIFICATION_TRACE = r"""
{
    "openrpc": "1.0.0-rc1",
    "info": {
        "version": "0.4.0",
        "title": "StarkNet Trace API",
        "license": {}
    },
    "servers": [],
    "methods": [
        {
            "name": "starknet_traceTransaction",
            "summary": "For a given executed transaction, return the trace of its execution, including internal calls",
            "description": "Returns the execution trace of the transaction designated by the input hash",
            "params": [
                {
                    "name": "transaction_hash",
                    "summary": "The hash of the transaction to trace",
                    "required": true,
                    "schema": {
                        "$ref": "./api/starknet_api_openrpc.json#/components/schemas/TXN_HASH"
                    }
                }
            ],
            "result": {
                "name": "trace",
                "description": "The function call trace of the transaction designated by the given hash",
                "schema": {
                    "$ref": "#/components/schemas/TRANSACTION_TRACE"
                }
            },
            "errors": [
                {
                    "$ref": "#/components/errors/INVALID_TXN_HASH"
                },
                {
                    "$ref": "#/components/errors/NO_TRACE_AVAILABLE"
                }
            ]
        },
        {
            "name": "starknet_simulateTransaction",
            "summary": "simulate a given transaction on the requested state, and generate the execution trace",
            "params": [
                {
                    "name": "block_id",
                    "description": "The hash of the requested block, or number (height) of the requested block, or a block tag, for the block referencing the state or call the transaction on.",
                    "required": true,
                    "schema": {
                        "$ref": "#/components/schemas/BLOCK_ID"
                    }
                },
                {
                    "name": "transactions",
                    "description": "The transactions to simulate",
                    "required": true,
                    "schema": {
                        "type": "array",
                        "description": "a sequence of transactions to simulate, running each transaction on the state resulting from applying all the previous ones",
                        "items": {
                            "$ref": "#/components/schemas/BROADCASTED_TXN"
                        }
                    }
                },
                {
                    "name": "simulation_flags",
                    "description": "describes what parts of the transaction should be executed",
                    "required": true,
                    "schema": {
                        "type": "array",
                        "items": {
                            "type": "string",
                            "enum": [
                                "SKIP_VALIDATE",
                                "SKIP_EXECUTE"
                            ],
                            "description": "Flags that indicate how to simulate a given transaction"
                        }
                    }
                }
            ],
            "result": {
                "name": "simulated_transactions",
                "description": "The execution trace and consuemd resources of the required transactions",
                "schema": {
                    "type": "array",
                    "items": {
                        "schema": {
                            "type": "object",
                            "properties": {
                                "transaction_trace": {
                                    "title": "the transaction's trace",
                                    "$ref": "#/components/schemas/TRANSACTION_TRACE"
                                },
                                "fee_estimation": {
                                    "title": "the transaction's resources and fee",
                                    "$ref": "#/components/schemas/FEE_ESTIMATE"
                                }
                            }
                        }
                    }
                }
            },
            "errors": [
                {
                    "$ref": "#/components/errors/CONTRACT_NOT_FOUND"
                },
                {
                    "$ref": "#/components/errors/CONTRACT_ERROR"
                },
                {
                    "$ref": "#/components/errors/BLOCK_NOT_FOUND"
                }
            ]
        },
        {
            "name": "starknet_traceBlockTransactions",
            "summary": "Retrieve traces for all transactions in the given block",
            "description": "Returns the execution traces of all transactions included in the given block",
            "params": [
                {
                    "name": "block_hash",
                    "summary": "The hash of the requested block",
                    "required": true,
                    "schema": {
                        "$ref": "#/components/schemas/BLOCK_HASH"
                    }
                }
            ],
            "result": {
                "name": "traces",
                "description": "The traces of all transactions in the block",
                "schema": {
                    "type": "array",
                    "items": {
                        "type": "object",
                        "description": "A single pair of transaction hash and corresponding trace",
                        "properties": {
                            "transaction_hash": {
                                "$ref": "#/components/schemas/FELT"
                            },
                            "trace_root": {
                                "$ref": "#/components/schemas/TRANSACTION_TRACE"
                            }
                        }
                    }
                }
            },
            "errors": [
                {
                    "$ref": "#/components/errors/INVALID_BLOCK_HASH"
                }
            ]
        }
    ],
    "components": {
        "contentDescriptors": {},
        "schemas": {
            "TRANSACTION_TRACE": {
                "oneOf": [
                    {
                        "name": "INVOKE_TXN_TRACE",
                        "type": "object",
                        "description": "the execution trace of an invoke transaction",
                        "properties": {
                            "validate_invocation": {
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            },
                            "execute_invocation": {
                                "description": "the trace of the __execute__ call or constructor call, depending on the transaction type (none for declare transactions)",
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            },
                            "fee_transfer_invocation": {
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            }
                        }
                    },
                    {
                        "name": "DECLARE_TXN_TRACE",
                        "type": "object",
                        "description": "the execution trace of a declare transaction",
                        "properties": {
                            "validate_invocation": {
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            },
                            "fee_transfer_invocation": {
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            }
                        }
                    },
                    {
                        "name": "DEPLOY_ACCOUNT_TXN_TRACE",
                        "type": "object",
                        "description": "the execution trace of a deploy account transaction",
                        "properties": {
                            "validate_invocation": {
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            },
                            "constructor_invocation": {
                                "description": "the trace of the __execute__ call or constructor call, depending on the transaction type (none for declare transactions)",
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            },
                            "fee_transfer_invocation": {
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            }
                        }
                    },
                    {
                        "name": "L1_HANDLER_TXN_TRACE",
                        "type": "object",
                        "description": "the execution trace of an L1 handler transaction",
                        "properties": {
                            "function_invocation": {
                                "description": "the trace of the __execute__ call or constructor call, depending on the transaction type (none for declare transactions)",
                                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
                            }
                        }
                    }
                ]
            },
            "SIMULATION_FLAG": {
                "type": "string",
                "enum": [
                    "SKIP_VALIDATE",
                    "SKIP_EXECUTE"
                ],
                "description": "Flags that indicate how to simulate a given transaction"
            },
            "NESTED_CALL": {
                "$ref": "#/components/schemas/FUNCTION_INVOCATION"
            },
            "FUNCTION_INVOCATION": {
                "allOf": [
                    {
                        "$ref": "#/components/schemas/FUNCTION_CALL"
                    },
                    {
                        "type": "object",
                        "properties": {
                            "caller_address": {
                                "title": "Caller Address",
                                "description": "The address of the invoking contract. 0 for the root invocation",
                                "$ref": "#/components/schemas/FELT"
                            },
                            "code_address": {
                                "title": "Code Address",
                                "description": "The address where the code for this contract is stored in the state",
                                "$ref": "#/components/schemas/FELT"
                            },
                            "entry_point_type": {
                                "$ref": "#/components/schemas/ENTRY_POINT_TYPE"
                            },
                            "call_type": {
                                "$ref": "#/components/schemas/CALL_TYPE"
                            },
                            "result": {
                                "title": "Invocation Result",
                                "description": "The value returned from the function invocation",
                                "type": "array",
                                "items": {
                                    "$ref": "#/components/schemas/FELT"
                                }
                            },
                            "calls": {
                                "title": "Nested Calls",
                                "description": "The calls made by this invocation",
                                "type": "array",
                                "items": {
                                    "$ref": "#/components/schemas/NESTED_CALL"
                                }
                            },
                            "events": {
                                "title": "Invocation Events",
                                "description": "The events emitted in this invocation",
                                "type": "array",
                                "items": {
                                    "$ref": "#/components/schemas/EVENT"
                                }
                            },
                            "messages": {
                                "title": "L1 Messages",
                                "description": "The messages sent by this invocation to L1",
                                "type": "array",
                                "items": {
                                    "$ref": "#/components/schemas/MSG_TO_L1"
                                }
                            }
                        }
                    }
                ]
            },
            "ENTRY_POINT_TYPE": {
                "type": "string",
                "enum": [
                    "EXTERNAL",
                    "L1_HANDLER",
                    "CONSTRUCTOR"
                ]
            },
            "CALL_TYPE": {
                "type": "string",
                "enum": [
                    "LIBRARY_CALL",
                    "CALL"
                ]
            },
            "FELT": {
                "$ref": "./api/starknet_api_openrpc.json#/components/schemas/FELT"
            },
            "FUNCTION_CALL": {
                "$ref": "./api/starknet_api_openrpc.json#/components/schemas/FUNCTION_CALL"
            },
            "EVENT": {
                "$ref": "./api/starknet_api_openrpc.json#/components/schemas/EVENT_CONTENT"
            },
            "MSG_TO_L1": {
                "$ref": "./api/starknet_api_openrpc.json#/components/schemas/MSG_TO_L1"
            },
            "BLOCK_HASH": {
                "$ref": "./api/starknet_api_openrpc.json#/components/schemas/BLOCK_HASH"
            },
            "BLOCK_ID": {
                "$ref": "./api/starknet_api_openrpc.json#/components/schemas/BLOCK_ID"
            },
            "BROADCASTED_TXN": {
                "$ref": "./api/starknet_api_openrpc.json#/components/schemas/BROADCASTED_TXN"
            },
            "FEE_ESTIMATE": {
                "$ref": "./api/starknet_api_openrpc.json#/components/schemas/FEE_ESTIMATE"
            }
        },
        "errors": {
            "NO_TRACE_AVAILABLE": {
                "code": 10,
                "message": "No trace available for transaction",
                "data": {
                    "type": "object",
                    "description": "Extra information on why trace is not available. Either it wasn't executed yet (RECEIVED), or the transaction failed (REJECTED)",
                    "properties": {
                        "status": {
                            "type": "string",
                            "enum": [
                                "RECEIVED",
                                "REJECTED"
                            ]
                        }
                    }
                }
            },
            "INVALID_BLOCK_HASH": {
                "code": 24,
                "message": "Invalid block hash"
            },
            "INVALID_TXN_HASH": {
                "code": 25,
                "message": "Invalid transaction hash"
            },
            "CONTRACT_NOT_FOUND": {
                "code": 20,
                "message": "Contract not found"
            },
            "BLOCK_NOT_FOUND": {
                "code": 24,
                "message": "Block not found"
            },
            "CONTRACT_ERROR": {
                "code": 40,
                "message": "Contract error"
            }
        }
    }
}
"""
